============
Installation
============

At the command line::

    $ easy_install featurevectormatrix

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv featurevectormatrix
    $ pip install featurevectormatrix